@@ -53,14 +53,16 @@ sub process {
 
     # don't run if {options_from_model} is set and is 0
 
-    my $option_flag = exists $args->{options_from_model}
+    my $option_flag
+        = exists $args->{options_from_model}
         ? $args->{options_from_model}
         : 1;
 
     return if !$option_flag;
-    
-    $self->options( [ $self->form->model->options_from_model( $self, $args ) ] );
-    
+
+    $self->options(
+        [ $self->form->model->options_from_model( $self, $args ) ] );
+
     return;
 }
 
